<div align="center">

## simplepy

**Python Common tools collection.**

</div>

<br>

### String generation
`from simplepy import string`

- Signature generation

- Random string generation
```
String(8) ---> 0xZ2U}`2
```

### File formatting

- Csv pretreatment

### Format conversion

- yaml
- xml to dict
- dict to xml

### Date processing

- date
- datetime

### History